import React from "react";
import {screen, render, fireEvent, getByRole} from "@testing-library/react"
import Todo from "./Todo";

describe("Todo", () => {
    const props = {
        id: 1,
        text: "Buy milk",
        completed: false,
        onToggle: jest.fn(),
        onDelete: jest.fn(),
    };

    it("should render todo text", () => {
        render(<Todo {...props} />);
        expect(screen.getByText(props.text)).toBeInTheDocument();
    });

    it("should call onToggle when checkbox is clicked", () => {
        render(<Todo {...props} />);
        fireEvent.click(screen.getByRole("checkbox"));
        expect(props.onToggle).toBeCalledWith(props.id);
    });

    it("should call onDelete when delete button is clicked", () => {
        render(<Todo {...props} />);
        fireEvent.click(screen.getByRole("button"));
        expect(props.onDelete).toBeCalledWith(props.id);
    })

    it("should have line-through style when completed is true", () => {
        render(<Todo {...props} completed={true} />);
        expect(screen.getByText(props.text)).toHaveStyle("text-decoration: line-through");
    })
})
